import { ElementRef, EventEmitter, OnInit, Renderer2 } from '@angular/core';
import { Sidebar } from 'primeng-lts/sidebar';
import { AlHeaderTemplateDirective } from './al-header-template.directive';
import { AlBottomSheetHeaderOptions } from './al-bottom-sheet-header-options.types';
import { AlFooterTemplateDirective } from './al-footer-template.directive';
import { AlBottomSheetFooterOptions } from './al-bottom-sheet-footer-options.types';
import * as i0 from "@angular/core";
export declare class AlBottomSheetComponent<T = any> extends Sidebar implements OnInit {
    el: ElementRef;
    renderer: Renderer2;
    /**
     * Allows define the width of the al-bottom-sheet.
     * The values can be in px, %, vh, rem etc...
     */
    width: string;
    heightActive: string;
    heightFullScreen: string;
    allowContent: boolean;
    headerOptions: AlBottomSheetHeaderOptions;
    footerOptions: AlBottomSheetFooterOptions;
    target: T | undefined;
    onPrimaryAction: EventEmitter<T>;
    onSecondaryAction: EventEmitter<T>;
    onTertiaryAction: EventEmitter<T>;
    onPrimaryFooterAction: EventEmitter<T>;
    onSecondaryFooterAction: EventEmitter<T>;
    onOpen: EventEmitter<any>;
    headerTemplate: AlHeaderTemplateDirective;
    footerTemplate: AlFooterTemplateDirective;
    state: 'opened' | 'closed' | 'collapsed';
    constructor(el: ElementRef, renderer: Renderer2);
    ngOnInit(): void;
    /**
     * Public method to open the bottom sheet
     */
    open(target?: T | undefined): void;
    /**
     * Public method to collapse the bottom sheet
     */
    collapse(): void;
    /**
     * Override hide method of Sidebar
     * Public method to close the bottom sheet
     */
    hide(): void;
    /**
     * Public method allow collapse and show the bottom-sheet
     */
    toggle(blAllowToggle?: boolean): void;
    /**
     * Center the bottom sheet
     */
    setBottomWidth(width?: string | null): void;
    /**
     * Set default config for p-sidebar
     */
    private defaultConfig;
    /**
     * Set styles of the sidebar
     * @param property is a property of css (height, width, margin, etc....)
     * @param value the value of the porpety
     */
    private setStyleSidebar;
    static ɵfac: i0.ɵɵFactoryDef<AlBottomSheetComponent<any>, never>;
    static ɵcmp: i0.ɵɵComponentDefWithMeta<AlBottomSheetComponent<any>, "al-bottom-sheet", never, { "width": "width"; "heightActive": "heightActive"; "heightFullScreen": "heightFullScreen"; "allowContent": "allowContent"; "headerOptions": "headerOptions"; "footerOptions": "footerOptions"; "target": "target"; }, { "onPrimaryAction": "onPrimaryAction"; "onSecondaryAction": "onSecondaryAction"; "onTertiaryAction": "onTertiaryAction"; "onPrimaryFooterAction": "onPrimaryFooterAction"; "onSecondaryFooterAction": "onSecondaryFooterAction"; "onOpen": "onOpen"; }, ["headerTemplate", "footerTemplate"], ["*"]>;
}
