/**
 *  AlNotificationTypes - an enumeration of different types of notifications.
 */
export declare const enum AlNotificationType {
    Information = 0,
    Warning = 1,
    Error = 2,
    Critical = 3,
    Success = 4,
    FakeEnthusiasm = 5
}
/**
 *  Defines a notification to be created.
 */
export declare class AlNotification {
    /**
     *  Indicates what type of notification this is.
     */
    type: AlNotificationType;
    /**
     *  The textual message to accompany this notification.
     */
    text: string;
    /**
     *  If provided, the number of milliseconds to display this notification before it is automatically dismissed.
     */
    autoDismiss?: number;
    /**
     * require flush the other notifications
     */
    flush?: boolean;
    /**
     *  The name of the icon to accompany this notification.
     */
    icon?: string;
    /**
     *  The text for the button to accompany this notification.
     */
    buttonText?: string;
    /**
     *  Constructor
     *
     *  @param text string The message text.
     *  @param type AlNotificationType The type of the notificatino (see AlNotificationType enum)
     *  @param number autoDismiss (optional) number of milliseconds before this notification should be automatically dismissed.
     */
    constructor(text: string, type?: AlNotificationType, autoDismiss?: number, flush?: boolean, icon?: string, buttonText?: string);
    /**
     *  Helper static constructor for Information notifications
     */
    static info(text: string, autoDismiss?: number, flush?: boolean, icon?: string, buttonText?: string): AlNotification;
    /**
     *  Helper static constructor for Warning notifications
     */
    static warning(text: string, autoDismiss?: number, flush?: boolean, icon?: string, buttonText?: string): AlNotification;
    /**
     *  Helper static constructor for Error notifications
     */
    static error(text: string, autoDismiss?: number, flush?: boolean, icon?: string, buttonText?: string): AlNotification;
    /**
     *  Helper static constructor for Error notifications
     */
    static success(text: string, autoDismiss?: number, flush?: boolean, icon?: string, buttonText?: string): AlNotification;
}
/**
 *  This class is used internally to describe a notification that is currently being displayed.
 */
export declare type AlActiveNotification = {
    definition: AlNotification;
    classes: string;
    displayed_on: number;
    expanded: boolean;
};
